==> xps_1.6.4.zip: xps/doc/xps.R <==
###################################################
### chunk number 1: 
###################################################
library(xps)


###################################################
### chunk number 2: 
###################################################
library(xps)


###################################################
### chunk number 3: 
###################################################
celdir <- paste(.path.package("xps"),"raw",sep="/")


###################################################
### chunk number 4: 
###################################################
scheme.test3 <- root.scheme(paste(.path.package("xps"),"schemes/SchemeTest3.root",sep="/"))


###################################################
### chunk number 5: 
###################################################
celfiles <- c("TestA1.CEL","TestA2.CEL")
data.test3 <- import.data(scheme.test3, "tmpdt_DataTest3", celdir=celdir, celfiles=celfiles, verbose=FALSE)


###################################################
### chunk number 6: 
###################################################
unlist(treeNames(data.test3))


###################################################
### chunk number 7: 
###################################################
celfiles <- c("TestB1.CEL","TestB2.CEL")
data.test3 <- addData(data.test3, celdir=celdir, celfiles=celfiles, verbose=FALSE)


###################################################
### chunk number 8: 
###################################################
getTreeNames(rootFile(data.test3))


###################################################
### chunk number 9: 
###################################################
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 10: 
###################################################
data.test3 <- attachInten(data.test3)


###################################################
### chunk number 11: 
###################################################
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 12: 
###################################################
subdata.test3 <- attachInten(data.test3, c("TestB1.cel","TestA2"))
tmp <- intensity(subdata.test3)
head(tmp)


###################################################
### chunk number 13: 
###################################################
data.test3 <- removeInten(data.test3)
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 14: 
###################################################
data.test3 <- attachMask(data.test3)
data.test3 <- attachInten(data.test3)


###################################################
### chunk number 15: hist
###################################################
hist(data.test3)


###################################################
### chunk number 16: boxplot
###################################################
boxplot(data.test3)


###################################################
### chunk number 17: image
###################################################
image(data.test3, names="TestA1.cel_MEAN")


###################################################
### chunk number 18: pmplot
###################################################
pmplot(data.test3)


###################################################
### chunk number 19: 
###################################################
data.test3 <- removeInten(data.test3)
data.test3 <- removeMask(data.test3)


###################################################
### chunk number 20: 
###################################################
library(xps)
scheme.test3 <- root.scheme(paste(.path.package("xps"),"schemes/SchemeTest3.root",sep="/"))
data.test3 <- root.data(scheme.test3, paste(.path.package("xps"),"rootdata/DataTest3_cel.root",sep="/"))


###################################################
### chunk number 21: 
###################################################
data.rma <- rma(data.test3, "tmpdt_Test3RMA", verbose=FALSE)


###################################################
### chunk number 22: 
###################################################
data.mas5 <- mas5(data.test3, "tmpdt_Test3MAS5", normalize=TRUE, sc=500, update=TRUE, verbose=FALSE)


###################################################
### chunk number 23: 
###################################################
expr.rma <- validData(data.rma)
expr.mas5 <- validData(data.mas5)


###################################################
### chunk number 24: plot
###################################################
plot(expr.rma[,1],expr.mas5[,1],log="xy",xlim=c(1,20000),ylim=c(1,20000))


###################################################
### chunk number 25: 
###################################################
call.mas5 <- mas5.call(data.test3,"tmpdt_Test3Call", verbose=FALSE)


###################################################
### chunk number 26: 
###################################################
call.dabg <- dabg.call(data.test3,"tmpdt_Test3DABG", verbose=FALSE)


###################################################
### chunk number 27: 
###################################################
pres.mas5 <- presCall(call.mas5)
head(pres.mas5)


###################################################
### chunk number 28: 
###################################################
pval.mas5 <- pvalData(call.mas5)
head(pval.mas5)


###################################################
### chunk number 29: hist-rma
###################################################
hist(data.rma)


###################################################
### chunk number 30: boxplot-rma
###################################################
boxplot(data.rma)


###################################################
### chunk number 31: mvaplot
###################################################
mvaplot(data.rma, pch=20, ylim=c(-2,2), names="TestB1.mdp_LEVEL")


###################################################
### chunk number 32: callplot
###################################################
callplot(call.mas5)


###################################################
### chunk number 33: 
###################################################
getTreeNames(rootFile(data.mas5))


###################################################
### chunk number 34: 
###################################################
bgrd <- export.root(rootFile(data.mas5),schemeFile(data.mas5),"PreprocesSet","TestA2","wbg","fBg","BgrdROOTOut.txt",as.dataframe=TRUE, verbose=FALSE)


###################################################
### chunk number 35: 
###################################################
wbg <- matrix(bgrd[,"BGRD"], ncol=ncols(schemeSet(data.mas5)), nrow=nrows(schemeSet(data.mas5)))


###################################################
### chunk number 36: image-bg
###################################################
image(log2(wbg))


###################################################
### chunk number 37: 
###################################################
prefltr <- PreFilter(mad=c(0.5), lothreshold=c(7.0,0.02,"mean"), hithreshold=c(10.5,80.0,"percent"))
str(prefltr)


###################################################
### chunk number 38: 
###################################################
data.rma@rootfile <- paste(.path.package("xps"),"rootdata/tmp_Test3RMA.root",sep="/")
data.rma@filedir  <- paste(.path.package("xps"),"rootdata",sep="/")


###################################################
### chunk number 39: 
###################################################
rma.pfr <- prefilter(data.rma, "tmpdt_Test3Prefilter", getwd(),
                     filter=prefltr, minfilters=2, verbose=FALSE)


###################################################
### chunk number 40: 
###################################################
tmp <- validData(rma.pfr)
head(tmp)
dim(tmp[tmp[,"FLAG"]==1,])


###################################################
### chunk number 41: 
###################################################
unifltr <- UniFilter(foldchange=c(1.3,"both"), unifilter=c(0.1,"pval"))


###################################################
### chunk number 42: 
###################################################
data.rma@rootfile <- paste(.path.package("xps"),"rootdata/tmp_Test3RMA.root",sep="/")
data.rma@filedir  <- paste(.path.package("xps"),"rootdata",sep="/")


###################################################
### chunk number 43: 
###################################################
rma.ufr <- unifilter(data.rma, "tmpdt_Test3Unifilter", getwd(),
                     unifltr, group=c("GrpA","GrpA","GrpB","GrpB"),
                     xps.fltr=rma.pfr, verbose=FALSE)


###################################################
### chunk number 44: 
###################################################
tmp <- validData(rma.ufr)
tmp


###################################################
### chunk number 45: 
###################################################
msk <- validFilter(rma.ufr)
tmp <- validData(rma.ufr, which="UnitName")
tmp <- cbind(tmp, msk)


###################################################
### chunk number 46: 
###################################################
tmp <- export.filter(rma.ufr, treetype="stt",
                     varlist="fUnitName:fName:fSymbol:fc:pval:flag",
                     as.dataframe=T, verbose=FALSE)
head(tmp)


###################################################
### chunk number 47: volcanoplot
###################################################
volcanoplot(rma.ufr, labels="fSymbol")


###################################################
### chunk number 48:  eval=FALSE
###################################################
## library(xps)
## libdir <- "/path/to/Affy/libraryfiles"
## anndir <- "/path/to/Affy/Annotation"
## scmdir <- "/path/to/CRAN/Workspaces/Schemes"


###################################################
### chunk number 49:  eval=FALSE
###################################################
## scheme.test3 <- import.expr.scheme("Scheme_Test3_na28", 
##                        filedir=scmdir,  
##                        paste(libdir,"Test3.CDF",sep="/"), 
##                        paste(libdir,"Test3_probe.tab",sep="/"), 
##                        paste(anndir,"Test3.na28.annot.csv",sep="/"))


###################################################
### chunk number 50:  eval=FALSE
###################################################
## scmdir <- "/path/to/CRAN/Workspaces/Schemes"
## scheme.test3 <- root.scheme(paste(scmdir,"SchemeTest3.root",sep="/"))


###################################################
### chunk number 51:  eval=FALSE
###################################################
## scheme.test3 <- import.expr.scheme("Scheme_Test3_na28",..., add.mask=TRUE)


###################################################
### chunk number 52:  eval=FALSE
###################################################
## library(Biobase)
## expr.rma <- validData(data.rma)
## minimalSet <- new("ExpressionSet", exprs = as.matrix(expr.rma))


###################################################
### chunk number 53:  eval=FALSE
###################################################
## vv <- minimalSet[1:5,1:3]
## featureNames(vv)
## sampleNames(vv)
## exprs(vv)


###################################################
### chunk number 54:  eval=FALSE
###################################################
## root.image(data.exon, treename="BreastA.cel", zlim=c(3,11), w=400, h=400)


###################################################
### chunk number 55:  eval=FALSE
###################################################
## root.density(data.exon, "*", w=400, h=400)
## root.density(data.x.rma, "*", w=400, h=400)


###################################################
### chunk number 56:  eval=FALSE
###################################################
## root.profile(data.x.rma, w=640, h=400)


###################################################
### chunk number 57:  eval=FALSE
###################################################
## root.graph2D(data.exon, "BreastA.cel", "BreastB.cel")
## root.graph2D(data.x.rma, "BreastA.mdp", "BreastB.mdp")


###################################################
### chunk number 58:  eval=FALSE
###################################################
## root.hist2D(data.exon, "BreastA.cel", "BreastB.cel", option="COLZ")
## root.hist2D(data.x.rma, "BreastA.mdp", "BreastB.mdp", option="COLZ")
## root.hist2D(data.x.rma, "BreastA.mdp", "BreastB.mdp", option="SURF2")


###################################################
### chunk number 59:  eval=FALSE
###################################################
## root.hist3D(data.exon, "BreastA.cel", "BreastB.cel", "BreastC.cel", option="SCAT")
## root.hist3D(data.x.rma, "BreastA.mdp", "BreastB.mdp", "BreastC.mdp", option="SCAT")


###################################################
### chunk number 60:  eval=FALSE
###################################################
## data.farms <- farms(data.test3,"tmp_Test3FARMS",verbose=FALSE)


###################################################
### chunk number 61:  eval=FALSE
###################################################
## data.dfw <- dfw(data.test3,"tmp_Test3DFW",verbose=FALSE)


###################################################
### chunk number 62:  eval=FALSE
###################################################
## call.ini <- ini.call(data.test3,"tmp_Test3INI",verbose=FALSE)

==> xps_1.10.2.zip: xps/doc/xps.R <==
###################################################
### chunk number 1: 
###################################################
#line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
library(xps)


###################################################
### chunk number 2: 
###################################################
#line 121 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
library(xps)


###################################################
### chunk number 3: 
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
celdir <- file.path(.path.package("xps"), "raw")


###################################################
### chunk number 4: 
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
scheme.test3 <- root.scheme(file.path(.path.package("xps"), "schemes", "SchemeTest3.root"))


###################################################
### chunk number 5: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
celfiles <- c("TestA1.CEL","TestA2.CEL")
data.test3 <- import.data(scheme.test3, "tmpdt_DataTest3", celdir=celdir, celfiles=celfiles, verbose=FALSE)


###################################################
### chunk number 6: 
###################################################
#line 143 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
unlist(treeNames(data.test3))


###################################################
### chunk number 7: 
###################################################
#line 148 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
celfiles <- c("TestB1.CEL","TestB2.CEL")
data.test3 <- addData(data.test3, celdir=celdir, celfiles=celfiles, verbose=FALSE)


###################################################
### chunk number 8: 
###################################################
#line 156 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
getTreeNames(rootFile(data.test3))


###################################################
### chunk number 9: 
###################################################
#line 200 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 10: 
###################################################
#line 206 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.test3 <- attachInten(data.test3)


###################################################
### chunk number 11: 
###################################################
#line 211 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 12: 
###################################################
#line 218 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
subdata.test3 <- attachInten(data.test3, c("TestB1.cel","TestA2"))
tmp <- intensity(subdata.test3)
head(tmp)


###################################################
### chunk number 13: 
###################################################
#line 226 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.test3 <- removeInten(data.test3)
tmp <- intensity(data.test3)
head(tmp)


###################################################
### chunk number 14: 
###################################################
#line 237 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.test3 <- attachMask(data.test3)
data.test3 <- attachInten(data.test3)


###################################################
### chunk number 15: hist
###################################################
#line 250 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
hist(data.test3)


###################################################
### chunk number 16: boxplot
###################################################
#line 259 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
boxplot(data.test3)


###################################################
### chunk number 17: image
###################################################
#line 268 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
image(data.test3, names="TestA1.cel_MEAN")


###################################################
### chunk number 18: pmplot
###################################################
#line 277 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
pmplot(data.test3)


###################################################
### chunk number 19: 
###################################################
#line 283 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.test3 <- removeInten(data.test3)
data.test3 <- removeMask(data.test3)


###################################################
### chunk number 20: 
###################################################
#line 300 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
library(xps)
scheme.test3 <- root.scheme(file.path(.path.package("xps"), "schemes", "SchemeTest3.root"))
data.test3 <- root.data(scheme.test3, file.path(.path.package("xps"),"rootdata", "DataTest3_cel.root"))


###################################################
### chunk number 21: 
###################################################
#line 318 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.rma <- rma(data.test3, "tmpdt_Test3RMA", verbose=FALSE)


###################################################
### chunk number 22: 
###################################################
#line 330 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.mas5 <- mas5(data.test3, "tmpdt_Test3MAS5", normalize=TRUE, sc=500, update=TRUE, verbose=FALSE)


###################################################
### chunk number 23: 
###################################################
#line 337 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
expr.rma <- validData(data.rma)
expr.mas5 <- validData(data.mas5)


###################################################
### chunk number 24: plot
###################################################
#line 344 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
plot(expr.rma[,1],expr.mas5[,1],log="xy",xlim=c(1,20000),ylim=c(1,20000))


###################################################
### chunk number 25: 
###################################################
#line 356 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
call.mas5 <- mas5.call(data.test3,"tmpdt_Test3Call", verbose=FALSE)


###################################################
### chunk number 26: 
###################################################
#line 361 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
call.dabg <- dabg.call(data.test3,"tmpdt_Test3DABG", verbose=FALSE)


###################################################
### chunk number 27: 
###################################################
#line 371 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
pres.mas5 <- presCall(call.mas5)
head(pres.mas5)


###################################################
### chunk number 28: 
###################################################
#line 376 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
pval.mas5 <- pvalData(call.mas5)
head(pval.mas5)


###################################################
### chunk number 29: hist-rma
###################################################
#line 395 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
hist(data.rma)


###################################################
### chunk number 30: boxplot-rma
###################################################
#line 404 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
boxplot(data.rma)


###################################################
### chunk number 31: mvaplot
###################################################
#line 413 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
mvaplot(data.rma, pch=20, ylim=c(-2,2), names="TestB1.mdp_LEVEL")


###################################################
### chunk number 32: callplot
###################################################
#line 422 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
callplot(call.mas5)


###################################################
### chunk number 33: 
###################################################
#line 432 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
getTreeNames(rootFile(data.mas5))


###################################################
### chunk number 34: 
###################################################
#line 440 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
bgrd <- export.root(rootFile(data.mas5),schemeFile(data.mas5),"PreprocesSet","TestA2","wbg","fBg","BgrdROOTOut.txt",as.dataframe=TRUE, verbose=FALSE)


###################################################
### chunk number 35: 
###################################################
#line 445 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
wbg <- matrix(bgrd[,"BGRD"], ncol=ncols(schemeSet(data.mas5)), nrow=nrows(schemeSet(data.mas5)))


###################################################
### chunk number 36: image-bg
###################################################
#line 452 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
image(log2(wbg))


###################################################
### chunk number 37: 
###################################################
#line 495 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
prefltr <- PreFilter(mad=c(0.5), lothreshold=c(7.0,0.02,"mean"), hithreshold=c(10.5,80.0,"percent"))
str(prefltr)


###################################################
### chunk number 38: 
###################################################
#line 502 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.rma@rootfile <- paste(.path.package("xps"),"rootdata/tmp_Test3RMA.root",sep="/")
data.rma@filedir  <- paste(.path.package("xps"),"rootdata",sep="/")


###################################################
### chunk number 39: 
###################################################
#line 507 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
rma.pfr <- prefilter(data.rma, "tmpdt_Test3Prefilter", getwd(),
                     filter=prefltr, minfilters=2, verbose=FALSE)


###################################################
### chunk number 40: 
###################################################
#line 513 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
tmp <- validData(rma.pfr)
head(tmp)
dim(tmp[tmp[,"FLAG"]==1,])


###################################################
### chunk number 41: 
###################################################
#line 547 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
unifltr <- UniFilter(foldchange=c(1.3,"both"), unifilter=c(0.1,"pval"))


###################################################
### chunk number 42: 
###################################################
#line 555 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
data.rma@rootfile <- paste(.path.package("xps"),"rootdata/tmp_Test3RMA.root",sep="/")
data.rma@filedir  <- paste(.path.package("xps"),"rootdata",sep="/")


###################################################
### chunk number 43: 
###################################################
#line 560 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
rma.ufr <- unifilter(data.rma, "tmpdt_Test3Unifilter", getwd(),
                     unifltr, group=c("GrpA","GrpA","GrpB","GrpB"),
                     xps.fltr=rma.pfr, verbose=FALSE)


###################################################
### chunk number 44: 
###################################################
#line 567 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
tmp <- validData(rma.ufr)
tmp


###################################################
### chunk number 45: 
###################################################
#line 577 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
msk <- validFilter(rma.ufr)
tmp <- validData(rma.ufr, which="UnitName")
tmp <- cbind(tmp, msk)


###################################################
### chunk number 46: 
###################################################
#line 585 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
tmp <- export.filter(rma.ufr, treetype="stt",
                     varlist="fUnitName:fName:fSymbol:fc:pval:flag",
                     as.dataframe=TRUE, verbose=FALSE)
head(tmp)


###################################################
### chunk number 47: volcanoplot
###################################################
#line 600 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
volcanoplot(rma.ufr, labels="fSymbol")


###################################################
### chunk number 48:  eval=FALSE
###################################################
## #line 633 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## library(xps)
## libdir <- "/path/to/Affy/libraryfiles"
## anndir <- "/path/to/Affy/Annotation"
## scmdir <- "/path/to/CRAN/Workspaces/Schemes"


###################################################
### chunk number 49:  eval=FALSE
###################################################
## #line 641 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## scheme.test3 <- import.expr.scheme("Scheme_Test3_na28", 
##                        filedir=scmdir,  
##                        paste(libdir,"Test3.CDF",sep="/"), 
##                        paste(libdir,"Test3_probe.tab",sep="/"), 
##                        paste(anndir,"Test3.na28.annot.csv",sep="/"))


###################################################
### chunk number 50:  eval=FALSE
###################################################
## #line 652 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## scmdir <- "/path/to/CRAN/Workspaces/Schemes"
## scheme.test3 <- root.scheme(paste(scmdir,"SchemeTest3.root",sep="/"))


###################################################
### chunk number 51:  eval=FALSE
###################################################
## #line 673 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## scheme.test3 <- import.expr.scheme("Scheme_Test3_na28",..., add.mask=TRUE)


###################################################
### chunk number 52:  eval=FALSE
###################################################
## #line 708 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## library(Biobase)
## expr.rma <- validData(data.rma)
## minimalSet <- new("ExpressionSet", exprs = as.matrix(expr.rma))


###################################################
### chunk number 53:  eval=FALSE
###################################################
## #line 718 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## vv <- minimalSet[1:5,1:3]
## featureNames(vv)
## sampleNames(vv)
## exprs(vv)


###################################################
### chunk number 54:  eval=FALSE
###################################################
## #line 741 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.image(data.exon, treename="BreastA.cel", zlim=c(3,11), w=400, h=400)


###################################################
### chunk number 55:  eval=FALSE
###################################################
## #line 762 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.density(data.exon, "*", w=400, h=400)
## root.density(data.x.rma, "*", w=400, h=400)


###################################################
### chunk number 56:  eval=FALSE
###################################################
## #line 778 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.profile(data.x.rma, w=640, h=400)


###################################################
### chunk number 57:  eval=FALSE
###################################################
## #line 798 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.graph2D(data.exon, "BreastA.cel", "BreastB.cel")
## root.graph2D(data.x.rma, "BreastA.mdp", "BreastB.mdp")


###################################################
### chunk number 58:  eval=FALSE
###################################################
## #line 820 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.hist2D(data.exon, "BreastA.cel", "BreastB.cel", option="COLZ")
## root.hist2D(data.x.rma, "BreastA.mdp", "BreastB.mdp", option="COLZ")
## root.hist2D(data.x.rma, "BreastA.mdp", "BreastB.mdp", option="SURF2")


###################################################
### chunk number 59:  eval=FALSE
###################################################
## #line 842 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## root.hist3D(data.exon, "BreastA.cel", "BreastB.cel", "BreastC.cel", option="SCAT")
## root.hist3D(data.x.rma, "BreastA.mdp", "BreastB.mdp", "BreastC.mdp", option="SCAT")


###################################################
### chunk number 60:  eval=FALSE
###################################################
## #line 889 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## data.farms <- farms(data.test3,"tmp_Test3FARMS",verbose=FALSE)


###################################################
### chunk number 61:  eval=FALSE
###################################################
## #line 895 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## data.dfw <- dfw(data.test3,"tmp_Test3DFW",verbose=FALSE)


###################################################
### chunk number 62:  eval=FALSE
###################################################
## #line 911 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmprUFF9j/R.INSTALL19781106/xps/inst/doc/xps.Rnw"
## call.ini <- ini.call(data.test3,"tmp_Test3INI",verbose=FALSE)
